@@ -61,14 +61,28 @@ my @testNumbers = (
 	"100001",
 	"100010",
 	"100011",
+	"100100",
 	"101010",
 	"1000001",
 	"1000101",
+	"1000100",
 	"1010000",
 	"1010001",
 	"1100001",
 	"1010101",
 	"101010101",
+	"እልፍ = 10000",
+	"አእላፍ = 100000",
+	"አእላፋት = 1000000",
+	"ትእልፊት = 10000000",
+	"ትእልፊታት = 100000000",
+	"ምእልፊት = 100000000000",
+	"1000000000000",
+	"10000000000000",
+	"ምእልፊታት = 1000000000000",
+	"100010000",
+	"100010100",
+	"101010100",
 	"3",
 	"30",
 	"33",
@@ -94,7 +108,15 @@ my @testNumbers = (
 
 my $n = new Convert::Ethiopic::Lite::Number;
 
+my $count = 1;
 foreach ( @testNumbers ) {
+	printf "%0i) ", $count++;
+
+	if ( /(.*?) = (\d+)/ ) {
+		print "<$1> ";
+		$_ = $2;
+	}
+
 	$n->number ( $_ );
 	my $number = $n->convert;
 	print "$_ => $number => ", $n->convert ( $number ), ".\n";
